summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
Diffstat (limited to 'lib')
-rw-r--r--lib/getoptlong.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/getoptlong.rb b/lib/getoptlong.rb
index 3ebbf3b1b6..4cfb5fbd27 100644
--- a/lib/getoptlong.rb
+++ b/lib/getoptlong.rb
@@ -151,7 +151,7 @@ class GetoptLong
@argument_flags = Hash.new
#
# Whether error messages are output to $deferr.
#
@quiet = FALSE
@@ -380,7 +380,7 @@ class GetoptLong
# Set an error (a protected method).
#
def set_error(type, message)
- $deferr.print("#{$0}: #{message}\n") if !@quiet
+ $stderr.print("#{$0}: #{message}\n") if !@quiet
@error = type
@error_message = message
@@ -151,7 +151,7 @@ class GetoptLong
#
- # Whether error messages are output to $deferr.
+ # Whether error messages are output to $stderr.
#